#! /bin/sh

#
# getconfigReaderSetup.sh		1.0  98/03/18
#
# script to be used from the getCurrentConfig() method in ReaderSetupImpl.java
#
# author: Geetha Srikantan
#
#    Exit value      Status
#    ----------      ------
#        0           success
#        1           Exit value 1 from GetCCReaderSetup
#        2           Exit value 2 from GetCCReaderSetup
#        3           Exit value 3 from GetCCReaderSetup
#        4           Exit value 4 from GetCCReaderSetup
#        5           shlock fails in this script - no operations performed
#        6           environment setup error in script
#
#



echo "In getconfigReaderSetup: at start"    


search_path() {
  for d in `echo $PATH | tr ':' ' '`
  do
     if [ -f $d/$1 -a -x $d/$1 ]
     then
        echo $d
	exit 6
     fi
  done
}


error() {
  echo "Error: $1" 2>&1
  exit 6
}



if [ -z "$JAVA_HOME" ]
then
  d=`search_path java`
  if [ -n "$d" ]
  then
    JAVA_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$JAVA_HOME" ]
  then
    JAVA_HOME=/opt/java
  fi
fi

if [ ! -x "$JAVA_HOME/bin/java" ]
then 
  error "Cannot find Java runtime"
fi


if [ -z "$ISP_HOME" ]
then
  d=`dirname $0`
  if [ -n "$d" ]
  then 
    ISP_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$ISP_HOME" ]
  then
    error "Cannot find default for ISP_HOME"
  fi
fi



echo $JAVA_HOME
echo $ISP_HOME

if [ ! -d "$ISP_HOME" ]
then 
  error "Invalid setting for ISP_HOME"
fi


ARCH=`uname -p`
echo $ARCH


export CLASSPATH
CLASSPATH=$JAVA_HOME/lib/classes.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/classes:$CLASSPATH
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/jndi.jar:$ISP_HOME/lib/ldap.jar
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/providerutil.jar
CLASSPATH=$ISP_HOME/lib/newsadmin.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/lib/ispadmin.zip:$CLASSPATH
CLASSPATH=/opt/SUNWcorba/lib/JavaIDL/classes.zip:$CLASSPATH


echo $CLASSPATH
#export LD_LIBRARY_PATH
#LD_LIBRARY_PATH=$JAVA_HOME/lib:$ISP_HOME/lib/solaris/$ARCH:$LD_LIBRARY_PATH

#cd $ISP_HOME



# Try to set file descriptors to max, fail silently if necessary
ulimit -S -n `ulimit -H -n` 2 >&1 > /dev/null



# Lock necessary files
#

#LOCK=/var/news/admin/state/lock.newsadmin
LOCK=/etc/opt/SUNWixsna/admin/state/lock.newsadmin
trap 'rm -f ${LOCK} ; exit 1' 1 2 3 15
if /opt/SUNWsns/bin/shlock -f ${LOCK} -p $$ ; then

	echo "In getconfigReaderSetup: after locking"

	# Call java program to extract config parameters and
	# store into specified file
	#

	echo "shlock done: Got here in getconfigReaderSetup.sh"

	/opt/SUNWsns/bin/setup/is_setup > /dev/null 2>&1
	setupDone=$?
	echo "setupDone is " $setupDone

	$JAVA_HOME/bin/java com.sun.newsadmin.server.GetCCReaderSetup $* setupDone:$setupDone
	
	outGetCCReaderSetup=$?
#	echo $outGetCCReaderSetup
	if [ $outGetCCReaderSetup = 255 ]; then
	  echo "GetCCReaderSetup fails to start"
	fi

	exit $outGetCCReaderSetup

else
	echo Fails: Locked by `cat ${LOCK}`
	exit 5
fi
