#! /bin/sh
# 
# setconfigFeedSetup                   1.0  98/03/01
#
# Script to be used from the doFeedSetup() method in FeedSetupImpl.java
#
#  author:  Geetha Srikantan
#
#    Exit value        Status
#    ----------        ------
#        0             success
#        1             Exit value 1 from SetCCFeedSetup
#        2             Exit value 2 from SetCCFeedSetup
#        3             Exit value 3 from SetCCFeedSetup
#        4             environment setup error in script
#        5             shlock fails in this script - no operations performed 
#        6             Setup_News failure
#        7             Setup_News exit when /var/news/storage/articles and
#  		       /var/news/state exist already.
#        8             Setup_News exit value when user-specified storage and 
#                      state locations don't exist
#        9             Incorrect entry for fully-qualified hostname
#        10            problem starting/stopping news server
#        11            Unknown setup status, cannot proceed
#
# NOTE: Setup_News may exit with non-zero values which overlap
# with some of the exit status mentioned above.
#

SAFE_INN_CONF=/etc/opt/SUNWixsna/admin/tmp/safe.inn.conf
SAFE_ETC_ALIASES=/etc/opt/SUNWixsna/admin/tmp/safe.etcAliases
SAFE_NEWS_ADMIN_CONFIG=/etc/opt/SUNWixsna/admin/tmp/safe.newsadmconfig

INN_CONF=/var/news/config/inn.conf
ETC_ALIASES=/etc/aliases
NEWS_ADMIN_CONFIG=/etc/opt/SUNWixsna/admin/state/newsadmconfig	

. /etc/opt/SUNWsns/innshellvars

echo "In setconfigFeedSetup: at start"

search_path() {
  for d in `echo $PATH | tr ':' ' '`
  do
    if [ -f $d/$1 -a -x $d/$1 ]
    then
      echo $d
      exit
    fi
  done
}


error() {
  echo "Error: $1" 2>&1
  exit 4
}


# copied this function from rc.news and modified it
# to check that innd process is executing
#
CheckForInnd () {
  oldpid=`ps -ef | grep innd | grep -v grep | awk '{print $2}'`
  if test -r $SERVERPID ; then
    if [ "X`cat $SERVERPID`" = "X$oldpid" ]; then
      kill -0 `cat $SERVERPID` > /dev/null 2>&1
      exitStatus=$?
      if [ $exitStatus -ne 0 ]; then
	# Server not running but pid exists
	return 1
      else
	return 0
      fi
    else
      # Case where a new innd gets started in between sleep
      return 1
    fi
  else
    # Case when server died
    return 1
  fi
}

if [ -z "$JAVA_HOME" ]
then
  d=`search_path java`
  if [ -n "$d" ]
  then
    JAVA_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$JAVA_HOME" ]
  then
    JAVA_HOME=/opt/java
  fi
fi

if [ ! -x "$JAVA_HOME/bin/java" ]
then 
  error "Cannot find Java runtime"
fi


if [ -z "$ISP_HOME" ]
then
  d=`dirname $0`
  if [ -n "$d" ]
  then 
    ISP_HOME=`cd $d/.. >/dev/null 2>&1 && pwd`
  fi
  if [ -z "$ISP_HOME" ]
  then
    error "Cannot find default for ISP_HOME"
  fi
fi

echo $JAVA_HOME
echo $ISP_HOME

if [ ! -d "$ISP_HOME" ]
then 
  error "Invalid setting for ISP_HOME"
fi


ARCH=`uname -p`


export CLASSPATH
CLASSPATH=$JAVA_HOME/lib/classes.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/classes:$CLASSPATH
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/jndi.jar:$ISP_HOME/lib/ldap.jar
CLASSPATH=$CLASSPATH:$ISP_HOME/lib/providerutil.jar
CLASSPATH=$ISP_HOME/lib/newsadmin.zip:$CLASSPATH
CLASSPATH=$ISP_HOME/lib/ispadmin.zip:$CLASSPATH
CLASSPATH=/opt/SUNWcorba/lib/JavaIDL/classes.zip:$CLASSPATH

#export LD_LIBRARY_PATH
#LD_LIBRARY_PATH=$JAVA_HOME/lib:$ISP_HOME/lib/solaris/$ARCH:$LD_LIBRARY_PATH

cd $ISP_HOME


# Try to set file descriptors to max, fail silently if necessary
ulimit -S -n `ulimit -H -n` 2 >&1 > /dev/null


# Lock necessary files
#


LOCK=/etc/opt/SUNWixsna/admin/state/lock.newsadmin
trap 'rm -f ${LOCK} ; exit 1' 1 2 3 15
if /opt/SUNWsns/bin/shlock -f ${LOCK} -p $$ ; then

  echo "In setconfigFeedSetup: after locking"


  # Call java program to update config parameters in the
  # relevant config files.

  /opt/SUNWsns/bin/setup/is_setup > /dev/null 2>&1
  setupDone=$?
  echo "setupDone is " $setupDone

  # The 1st argument is a filename. 
  # The Java program will write data to this file, which is to
  # be used as input to the Setup_News script.
  #
  setup_input=$1
  
  # Change permissions on files that will be modified by Java code
  #
  chmod u+w $ETC_ALIASES
  chmod u+w $NEWS_ADMIN_CONFIG
  if [ $setupDone -eq 0 ] ; then
    chmod u+w $INN_CONF
  fi
  
  # Note the order of input arguments is important! $* first, then rest
  #
  /usr/java/bin/java com.sun.newsadmin.server.SetCCFeedSetup $* setupDone:$setupDone
  
  # Save exit value
  #
  outSetCCFeedSetup=$?
  echo "SetCCfeedSetup output is: $outSetCCFeedSetup"
  
  if [ $outSetCCFeedSetup -ne 0 ] ; then
    # add stuff here to UNDO changes to config files
    # exit with this exit-value
    cp $SAFE_ETC_ALIASES $ETC_ALIASES
    cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG
    chmod u-w $ETC_ALIASES
    chmod u-w $NEWS_ADMIN_CONFIG
    if [ $setupDone -eq 0 ]; then
      # undo edits to /var/news/config/inn.conf also
      cp $SAFE_INN_CONF $INN_CONF
      chmod u-w $INN_CONF
    fi
    exit $outSetCCFeedSetup
  fi # case where $setCCFeedSetup != 0
  

  # Continue on, if exit value from Java program was 0
  #
  
  # If this is not the first setup of news, then need shutdown and
  # restart the server. For a first-time setup, start the server after
  # invoking Setup_News.
  # if any of the operations fail, roll-back changes to config files
  # and restore their permissions, before exiting with failure codes.
  #
  opStatus=0
  if [ $setupDone -eq 0 ] ; then
    /etc/init.d/news.server stop
    opStatus=$?
    if [ $opStatus -eq 0 ] ; then 
      /etc/init.d/news.server start
      opStatus=$?
    fi 

    # If news server stop/start failed, then undo edits to 
    # /var/news/config/inn.conf, newsadmconfig and /etc/aliases 
    # and restore permissions, then exit with failure status
    #
    if [ $opStatus -ne 0 ] ; then
      cp $SAFE_ETC_ALIASES $ETC_ALIASES
      cp $SAFE_INN_CONF $INN_CONF
      cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG 
      chmod u-w $NEWS_ADMIN_CONFIG
      chmod u-w $ETC_ALIASES
      chmod u-w $INN_CONF
      exit 10
    fi # news.server stop/start failed

    # Everything worked fine..restore config file permissions
    # and exit with success status
    #
    if [ $opStatus -eq 0 ] ; then
      chmod u-w $NEWS_ADMIN_CONFIG
      chmod u-w $ETC_ALIASES
      chmod u-w $INN_CONF
      exit 0
    fi

  else # setupDone != 0
    if [ $setupDone -eq 1 ] ; then
      /opt/SUNWsns/bin/Setup_News < $setup_input
      opStatus=$?
      if [ $opStatus -eq 0 ] ; then
	/etc/init.d/news.server start
	opStatus=$?
	if [ $opStatus -ne 0 ] ; then
	  # server start problem
	  # restore config files and their permissions
	  # then exit wil failure status
	  #
	  cp $SAFE_ETC_ALIASES $ETC_ALIASES
	  cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG 
	  chmod u-w $NEWS_ADMIN_CONFIG
	  chmod u-w $ETC_ALIASES
	  exit 10
	else
	  # everything worked just fine..
	  # exit with success status after changing file permissions
	  #
	  chmod u-w $NEWS_ADMIN_CONFIG
	  chmod u-w $ETC_ALIASES
	  exit 0
	fi
      else # Setup_News failure 
	echo "Failure during execution of /opt/SUNWsns/bin/Setup_News"
	echo "Exit value is: " $opStatus
	# Previous edits to newsadmconfig and /etc/aliases need to be undone
	cp $SAFE_ETC_ALIASES $ETC_ALIASES
	cp $SAFE_NEWS_ADMIN_CONFIG $NEWS_ADMIN_CONFIG
	chmod u-w $ETC_ALIASES
	chmod u-w $NEWS_ADMIN_CONFIG
	# Then exit with appropriate status
	if [ $opStatus -eq 7 -o $opStatus -eq 8 -o $opStatus -eq 9 ] ; then
	  exit $opStatus 
	else
	  exit 6
	fi
      fi # non-zero exit value from Setup_News
    else # setupDone != 0 and setupDone != 1
      echo "Unknown setup status, cannot proceed"
      chmod u-w $NEWS_ADMIN_CONFIG
      chmod u-w $ETC_ALIASES
      exit 11
    fi # setupDone=1
  fi # setupDone !=0
  
else 
  echo Fails: Locked by `cat ${LOCK}`
  exit 5
fi



